@@ -1,3 +1,6 @@
+from loggerpy import Level
+
+
 class LoggerNameException(Exception):
     def __init__(self, message):
         self.message = message
@@ -7,8 +10,8 @@ class LoggerNameException(Exception):
 
 
 class LoggerLevelException(Exception):
-    def __init__(self, level):
-        self.message = 'No level \'{}\' found.'.format(level.upper())
+    def __init__(self, level: Level):
+        self.message = f"No level '{level.value}' found."
 
     def __str__(self):
         return self.message
